/**
 * Branch on GitHub.
 */
export class GithubBranch extends Branch {
    constructor(owner: any, name: any, options: any);
    /**
     * Writes content into the branch
     * {@link https://developer.github.com/v3/git/blobs/#get-a-blob}
     * @param {ContentEntry} entry
     * @return {Promise<ContentEntry>} written content with sha values set
     */
    writeEntry(entry: ContentEntry): Promise<ContentEntry>;
    /**
     * {@link https://developer.github.com/v3/git/trees/#create-a-tree}
     * {@link https://developer.github.com/v3/git/commits/#create-a-commit}
     * {@link https://developer.github.com/v3/git/refs/#update-a-reference}
     * @param {string} message
     * @param {ContentEntry[]} entries
     * @param {Object} [options]
     */
    commit(message: string, entries: ContentEntry[], options?: any): Promise<any>;
    /**
     * {@link https://developer.github.com/v3/repos/contents/#get-repository-content}
     * @param {string} name
     */
    entry(name: string): Promise<any>;
    entries(patterns: any): AsyncGenerator<{
        [x: string]: any;
        readonly isCollection: boolean;
        readonly types: string[];
        readonly mode: number;
    } | LazyBufferContentEntry, void, unknown>;
    /**
     * https://developer.github.com/v3/repos/contents/
     * @param {AsyncIterator<ContentEntry>} entries
     */
    removeEntries(entries: AsyncIterator<ContentEntry>): Promise<void>;
    #private;
}
import { Branch } from "repository-provider";
import { ContentEntry } from "content-entry";
declare const LazyBufferContentEntry_base: new (name: string) => {
    readonly string: string;
    readonly readStream: ReadableStream<any>;
    readonly isEmpty: boolean;
    readonly size: number;
    getReadStream(): Promise<ReadableStream<any>>;
    readonly isBlob: boolean;
    readonly types: string[];
    readonly buffer: Uint8Array;
    readonly encoding: string;
    equalsContent(other: ContentEntry): Promise<boolean>;
    name: string;
    readonly isCollection: boolean;
    readonly mode: number;
    readonly mtime: Date;
    readonly isDeleted: boolean;
    readonly isExistent: boolean;
    toJSON(): {
        name: string;
        isBlob: boolean;
        isCollection: boolean;
    };
    equals(other: any): Promise<boolean>;
};
declare class LazyBufferContentEntry extends LazyBufferContentEntry_base {
    constructor(name: any, mode: any, branch: any);
    branch: any;
    get buffer(): Promise<any>;
    getBuffer(): Promise<any>;
    #private;
}
export {};
