/**
 * Github pull request.
 */
export class GithubPullRequest extends PullRequest {
    /**
     * All valid merge methods.
     * @return {Set<string>} valid merge methods
     */
    static validMergeMethods: Set<string>;
    static get attributes(): {
        maintainer_can_modify: import("pacc").AttributeDefinition;
        body: import("pacc").AttributeDefinition;
        title: import("pacc").AttributeDefinition;
        url: import("pacc").AttributeDefinition;
        state: {
            default: string;
            values: Set<string>;
            type: string;
            isKey: boolean;
            writable: boolean;
            mandatory: boolean;
            private?: boolean;
            depends?: string;
            additionalAttributes: string[];
            description?: string;
            set?: Function;
            get?: Function;
            env?: string | string[];
        };
        locked: import("pacc").AttributeDefinition;
        merged: import("pacc").AttributeDefinition;
        draft: import("pacc").AttributeDefinition;
        dry: import("pacc").AttributeDefinition;
        empty: import("pacc").AttributeDefinition;
        id: import("pacc").AttributeDefinition;
        name: import("pacc").AttributeDefinition;
        description: import("pacc").AttributeDefinition;
    };
    /**
     * {@link https://developer.github.com/v3/pulls/#list-pull-requests}
     * @param {Repository} repository
     * @param {Object} filter
     */
    static list(repository: Repository, filter?: any): AsyncGenerator<GithubPullRequest, void, unknown>;
    /**
     * {@link https://developer.github.com/v3/pulls/#create-a-pull-request}
     * @param {Branch} source
     * @param {Branch} destination
     * @param {Object} [options]
     */
    static open(source: Branch, destination: Branch, options?: any): Promise<GithubPullRequest>;
    /**
     * {@link https://developer.github.com/v3/pulls/#merge-a-pull-request}
     */
    _merge(method?: string): Promise<void>;
}
import { PullRequest } from "repository-provider";
import { Repository } from "repository-provider";
import { Branch } from "repository-provider";
